iCom listener — PyMedPhys

Toggle navigation sidebar
Toggle in-page Table of Contents

# iCom listener

    usage: pymedphys icom [-h] {listen} ...

## Positional Arguments

`icom`

  Possible choices: listen

## Sub-commands

### listen

Connect to an Elekta iCom stream and store the records to a directory. Whenever the Linac delivered MV radiation these records will be indexed by Patient ID and name. Anytime MV radiation is not delivered, these records are discarded. WARNING: This listener is susceptible to the bug documented at <https://github.com/pymedphys/pymedphys/issues/849>.

    pymedphys icom listen [-h] ip directory

#### Positional Arguments

`ip`

  The IP address of the Linac.

`directory`

  The output directory to store the iCom records.